@@ -1,4 +1,5 @@
-""" A client library for accessing Task Badger """
+"""A client library for accessing Taskbadger API"""
+
 from .client import AuthenticatedClient, Client
 
 __all__ = (
