@@ -1,5 +1,6 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional, Union
+from typing import Any, Optional, Union
+from uuid import UUID
 
 import httpx
 
@@ -14,44 +15,39 @@ def _get_kwargs(
     organization_slug: str,
     project_slug: str,
     *,
-    client: AuthenticatedClient,
-    json_body: TaskRequest,
-    x_taskbadger_monitor: Union[Unset, str] = UNSET,
-) -> Dict[str, Any]:
-    url = "{}/api/{organization_slug}/{project_slug}/tasks/".format(
-        client.base_url, organization_slug=organization_slug, project_slug=project_slug
-    )
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
+    body: TaskRequest,
+    x_taskbadger_monitor: Union[Unset, UUID] = UNSET,
+) -> dict[str, Any]:
+    headers: dict[str, Any] = {}
     if not isinstance(x_taskbadger_monitor, Unset):
         headers["X-TASKBADGER-MONITOR"] = x_taskbadger_monitor
 
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: dict[str, Any] = {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "json": json_json_body,
+        "url": f"/api/{organization_slug}/{project_slug}/tasks/",
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Task]:
-    if response.status_code == HTTPStatus.CREATED:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Task]:
+    if response.status_code == 201:
         response_201 = Task.from_dict(response.json())
 
         return response_201
     if client.raise_on_unexpected_status:
-        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
+        raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[Task]:
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Task]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -65,8 +61,8 @@ def sync_detailed(
     project_slug: str,
     *,
     client: AuthenticatedClient,
-    json_body: TaskRequest,
-    x_taskbadger_monitor: Union[Unset, str] = UNSET,
+    body: TaskRequest,
+    x_taskbadger_monitor: Union[Unset, UUID] = UNSET,
 ) -> Response[Task]:
     """Create Task
 
@@ -75,8 +71,8 @@ def sync_detailed(
     Args:
         organization_slug (str):
         project_slug (str):
-        x_taskbadger_monitor (Union[Unset, str]):
-        json_body (TaskRequest):
+        x_taskbadger_monitor (Union[Unset, UUID]):
+        body (TaskRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -89,13 +85,11 @@ def sync_detailed(
     kwargs = _get_kwargs(
         organization_slug=organization_slug,
         project_slug=project_slug,
-        client=client,
-        json_body=json_body,
+        body=body,
         x_taskbadger_monitor=x_taskbadger_monitor,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -107,8 +101,8 @@ def sync(
     project_slug: str,
     *,
     client: AuthenticatedClient,
-    json_body: TaskRequest,
-    x_taskbadger_monitor: Union[Unset, str] = UNSET,
+    body: TaskRequest,
+    x_taskbadger_monitor: Union[Unset, UUID] = UNSET,
 ) -> Optional[Task]:
     """Create Task
 
@@ -117,22 +111,22 @@ def sync(
     Args:
         organization_slug (str):
         project_slug (str):
-        x_taskbadger_monitor (Union[Unset, str]):
-        json_body (TaskRequest):
+        x_taskbadger_monitor (Union[Unset, UUID]):
+        body (TaskRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Task]
+        Task
     """
 
     return sync_detailed(
         organization_slug=organization_slug,
         project_slug=project_slug,
         client=client,
-        json_body=json_body,
+        body=body,
         x_taskbadger_monitor=x_taskbadger_monitor,
     ).parsed
 
@@ -142,8 +136,8 @@ async def asyncio_detailed(
     project_slug: str,
     *,
     client: AuthenticatedClient,
-    json_body: TaskRequest,
-    x_taskbadger_monitor: Union[Unset, str] = UNSET,
+    body: TaskRequest,
+    x_taskbadger_monitor: Union[Unset, UUID] = UNSET,
 ) -> Response[Task]:
     """Create Task
 
@@ -152,8 +146,8 @@ async def asyncio_detailed(
     Args:
         organization_slug (str):
         project_slug (str):
-        x_taskbadger_monitor (Union[Unset, str]):
-        json_body (TaskRequest):
+        x_taskbadger_monitor (Union[Unset, UUID]):
+        body (TaskRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -166,13 +160,11 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         organization_slug=organization_slug,
         project_slug=project_slug,
-        client=client,
-        json_body=json_body,
+        body=body,
         x_taskbadger_monitor=x_taskbadger_monitor,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -182,8 +174,8 @@ async def asyncio(
     project_slug: str,
     *,
     client: AuthenticatedClient,
-    json_body: TaskRequest,
-    x_taskbadger_monitor: Union[Unset, str] = UNSET,
+    body: TaskRequest,
+    x_taskbadger_monitor: Union[Unset, UUID] = UNSET,
 ) -> Optional[Task]:
     """Create Task
 
@@ -192,15 +184,15 @@ async def asyncio(
     Args:
         organization_slug (str):
         project_slug (str):
-        x_taskbadger_monitor (Union[Unset, str]):
-        json_body (TaskRequest):
+        x_taskbadger_monitor (Union[Unset, UUID]):
+        body (TaskRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Task]
+        Task
     """
 
     return (
@@ -208,7 +200,7 @@ async def asyncio(
             organization_slug=organization_slug,
             project_slug=project_slug,
             client=client,
-            json_body=json_body,
+            body=body,
             x_taskbadger_monitor=x_taskbadger_monitor,
         )
     ).parsed
