@@ -1,6 +1,7 @@
 import datetime
 import logging
 import os
+import warnings
 from typing import Any
 
 from taskbadger.exceptions import (
@@ -327,25 +328,32 @@ class Task:
         """Update the task status"""
         self.update(status=status)
 
-    def increment_progress(self, amount: int, value_step: int = None, rate_limit: int = None):
+    def increment_progress(self, amount: int):
+        warnings.warn(
+            "'task.increment_progress' will be removed in v1.7.0. Use 'task.increment_value' instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        self.increment_value(amount)
+
+    def increment_value(self, amount: int):
         """Increment the task progress by adding the specified amount to the current value.
         If the task value is not set it will be set to `amount`.
-
-        Arguments:
-            amount: The amount to increment the task value by.
-            value_step: The minimum change in value required to trigger an update.
-            rate_limit: The minimum interval between updates in seconds.
-
-        If either `value_step` or `rate_limit` is set, the task will only be updated if the
-        specified conditions are met. If both are set, the task will be updated if either
-        condition is met.
         """
         value = self._task.value
         value_norm = value if value is not UNSET and value is not None else 0
         new_amount = value_norm + amount
-        self.update_progress(new_amount, value_step, rate_limit)
+        self.update(value=new_amount)
 
     def update_progress(self, value: int, value_step: int = None, rate_limit: int = None):
+        warnings.warn(
+            "'task.update_progress' will be removed in v1.7.0. Use 'task.update_value' instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        self.update_value(value, value_step, rate_limit)
+
+    def update_value(self, value: int, value_step: int = None, rate_limit: int = None) -> bool:
         """Update task progress.
 
         Arguments:
@@ -353,6 +361,9 @@ class Task:
             value_step: The minimum change in value required to trigger an update.
             rate_limit: The minimum interval between updates in seconds.
 
+        Returns:
+            bool: True if the task was updated, False otherwise
+
         If either `value_step` or `rate_limit` is set, the task will only be updated if the
         specified conditions are met. If both are set, the task will be updated if either
         condition is met.
@@ -362,6 +373,8 @@ class Task:
         value_check = value_step and self._check_update_value_interval(value, value_step)
         if skip_check or time_check or value_check:
             self.update(value=value)
+            return True
+        return False
 
     def set_value_max(self, value_max: int):
         """Set the `value_max`."""
@@ -416,16 +429,21 @@ class Task:
         """Add tags to the task."""
         self.update(tags=tags)
 
-    def ping(self, rate_limit=None):
+    def ping(self, rate_limit=None) -> bool:
         """Update the task without changing any values. This can be used in conjunction
         with 'stale_timeout' to indicate that the task is still running.
 
         Arguments:
             rate_limit: The minimum interval between pings in seconds. If set this will only
                 update the task if the last update was more than `rate_limit` seconds ago.
+
+        Returns:
+            bool: True if the task was updated, False otherwise
         """
         if self._check_update_time_interval(rate_limit):
             self.update()
+            return True
+        return False
 
     @property
     def tags(self):
